@@ -1,22 +1,18 @@
 """Summary of documentation components:
 
-* ``forge`` is used to define and reuse documentation for API request parameters
-* ``apidoc`` is used to generate rst sources for **modules**
-* ``autosummary`` is used to generate rst sources for **packages and summaries**
-* ``automodapi`` + ``pyinaturalist.docs.model_docs`` are used to generate model
-  documentation based on ``attrs`` fields + metadata
-* ``intersphinx`` is used to insert links to other projects' docs
+* `forge` is used to define and reuse documentation for API request parameters
+* `apidoc` is used to generate rst sources for **modules**
+* `autosummary` is used to generate rst sources for **packages and summaries**
+* `automodapi` + `pyinaturalist.docs.model_docs` are used to generate model
+  documentation based on `attrs` fields + metadata
+* `intersphinx` is used to insert links to other projects' docs
 * Jinja templates provide some additional customization:
-    * Show a class summary for ``pyinaturalist.models`` package
-    * Show a function summary for ``pyinaturalist.v*`` packages
-    * Show a function summary for all modules except ``pyinaturalist.models.*``
-* Some Sphinx builder hooks copy some content so it can be accessed relative to ``docs`` dir
+    * Show a class summary for `pyinaturalist.models` package
+    * Show a function summary for `pyinaturalist.v*` packages
+    * Show a function summary for all modules except `pyinaturalist.models.*`
+* Some Sphinx builder hooks copy some content so it can be accessed relative to `docs` dir
 * Some CSS and JS adds collapsible drop-down container
 * On Readthedocs, CSS and JS is automatically added for a version dropdown
-
-TODO:
-* Customization for package-level docs that can be done with module docstrings instead of templates?
-* Automatically generate list of versions for version dropdown?
 """
 # flake8: noqa: E402
 import sys
@@ -33,20 +29,21 @@ except ImportError:
 # Add project path so we can import our package
 sys.path.insert(0, '..')
 from pyinaturalist import __version__
-from pyinaturalist.constants import DOCS_DIR, PROJECT_DIR, EXAMPLES_DIR, SAMPLE_DATA_DIR
+from pyinaturalist.constants import DOCS_DIR, EXAMPLES_DIR, PROJECT_DIR, SAMPLE_DATA_DIR
 from pyinaturalist.docs.model_docs import document_models
 
 # Relevant doc directories used in extension settings
 CSS_DIR = join(DOCS_DIR, '_static')
 MODULE_DOCS_DIR = 'modules'
 PACKAGE_DIR = join(PROJECT_DIR, 'pyinaturalist')
+TEMPLATE_DIR = join(DOCS_DIR, '_templates')
 
 # Symlink paths for static content outside docs directory
 DATA_DIR_SYMLINK = join(DOCS_DIR, 'sample_data')
 NOTEBOOK_DIR_COPY = join(DOCS_DIR, 'examples')
 
 # General information about the project.
-copyright = '2021, Nicolas Noé, Jordan Cook'
+copyright = '2022, Nicolas Noé, Jordan Cook'
 exclude_patterns = ['_build', f'{MODULE_DOCS_DIR}/pyinaturalist.rst']
 master_doc = 'index'
 needs_sphinx = '4.0'
@@ -60,6 +57,7 @@ extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
     'sphinx.ext.autosectionlabel',
+    'sphinx.ext.extlinks',
     'sphinx.ext.intersphinx',
     'sphinx.ext.napoleon',
     'sphinx_autodoc_typehints',
@@ -84,10 +82,21 @@ myst_enable_extensions = [
 
 nbsphinx_allow_errors = True
 
+# Prefixes to shorten common links
+extlinks = {
+    'issue': ('https://github.com/niconoe/pyinaturalist/issues/%s', 'issue #%s'),
+    'v0': ('https://www.inaturalist.org/pages/api+reference#', '%s'),
+    'v1': ('https://api.inaturalist.org/v1/docs/#/%s', '%s'),
+    'v2': ('https://api.inaturalist.org/v2/docs/#/%s', '%s'),
+}
+
 # Enable automatic links to other projects' Sphinx docs
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
     'requests': ('https://requests.readthedocs.io/en/master/', None),
+    'requests_cache': ('https://requests-cache.readthedocs.io/en/stable/', None),
+    'requests_ratelimiter': ('https://requests-ratelimiter.readthedocs.io/en/latest/', None),
+    'urllib3': ('https://urllib3.readthedocs.io/en/stable/', None),
 }
 
 # Generate labels in the format <page>:<section>
@@ -118,8 +127,15 @@ autodoc_typehints = 'none'
 # apidoc settings
 apidoc_module_dir = PACKAGE_DIR
 apidoc_output_dir = MODULE_DOCS_DIR
-apidoc_excluded_paths = ['docs/*', 'models/*', 'node_api.py', 'rest_api.py']
-apidoc_extra_args = ['--templatedir=_templates']
+apidoc_excluded_paths = [
+    'controllers/*',
+    'docs/*',
+    'models/*',
+    'constants.py',
+    'node_api.py',
+    'rest_api.py',
+]
+apidoc_extra_args = [f'--templatedir={TEMPLATE_DIR}']  # Note: Must be an absolute path
 apidoc_module_first = True
 apidoc_separate_modules = True
 apidoc_toc_file = False
@@ -127,7 +143,7 @@ apidoc_toc_file = False
 # autosummary + automodapi settings
 automodapi_inheritance_diagram = False
 automodapi_toctreedirnm = MODULE_DOCS_DIR
-automodsumm_inherited_members = False
+automodsumm_inherited_members = True
 autosummary_generate = True
 autosummary_generate_overwrite = True
 autosummary_imported_members = False
