@@ -1,4 +1,4 @@
-from typing import BinaryIO, Optional, Tuple
+from typing import BinaryIO, List, Optional, Tuple
 
 import requests
 
@@ -32,10 +32,13 @@ class Photo(BaseModel):
         options=ALL_LICENSES,
         doc='Creative Commons license code',
     )
+    observation_id: int = field(default=None, doc='Associated observation ID')
     original_dimensions: Tuple[int, int] = field(
         converter=format_dimensions, default=(0, 0), doc='Dimensions of original image'
     )
     url: str = field(default=None, doc='Image URL; see properties for URLs of specific image sizes')
+    user_id: int = field(default=None, doc='Associated user ID')
+    uuid: str = field(default=None)
     _url_format: str = field(init=False, repr=False, default=None)
 
     # Unused attributes
@@ -128,7 +131,7 @@ class Photo(BaseModel):
         img.show()
 
     @property
-    def row(self) -> TableRow:
+    def _row(self) -> TableRow:
         return {
             'ID': self.id,
             'License': self.license_code,
@@ -136,16 +139,20 @@ class Photo(BaseModel):
             'URL': self.original_url,
         }
 
-    def __str__(self) -> str:
-        return f'[{self.id}] {self.original_url} ({self.license_code}, {self.dimensions_str})'
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['id', 'license_code', 'url']
 
 
 @define_model
 class IconPhoto(Photo):
     """:fa:`camera` Class used for displaying an iconic taxon in place of a taxon photo"""
 
+    iconic_taxon_name: str = field(default=None, doc='Iconic taxon name')
+
     def __attrs_post_init__(self):
         self._url_format = self.url.replace('.png', '-{size}px.png')
+        self.url = self.medium_url
 
     @classmethod
     def from_iconic_taxon(cls, iconic_taxon_name: str):
@@ -161,5 +168,6 @@ class IconPhoto(Photo):
         size = size.replace('thumbnail', 'square').replace('thumb', 'square')
         return self._url_format.format(size=ICON_SIZES.get(size, 'square'))
 
-    def __str__(self) -> str:
-        return self.url
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['iconic_taxon_name', 'url']
