@@ -11,6 +11,7 @@ from pyinaturalist.constants import (
     JsonResponse,
     TableRow,
 )
+from pyinaturalist.converters import ensure_list
 from pyinaturalist.docs import EMOJI
 from pyinaturalist.models import (
     BaseModel,
@@ -37,8 +38,11 @@ class Taxon(BaseModel):
     include nested ``ancestors``, ``children``, and results from :py:func:`.get_taxa_autocomplete`.
     """
 
+    ancestry: str = field(default=None, doc='Slash-delimited string of ancestor IDs', repr=False)
     ancestor_ids: List[int] = field(
-        factory=list, doc='Taxon IDs of ancestors, from highest rank to lowest'
+        factory=list,
+        converter=ensure_list,  # Handle arrays when converting from a dataframe
+        doc='Taxon IDs of ancestors, from highest rank to lowest',
     )
     complete_rank: str = field(
         default=None, doc='Complete or "leaf taxon" rank, e.g. species or subspecies'
@@ -136,11 +140,21 @@ class Taxon(BaseModel):
     # universal_search_rank: int = field(default=None)
 
     def __attrs_post_init__(self):
+        # Look up iconic taxon name, if only ID is provided
         if not self.iconic_taxon_name:
             self.iconic_taxon_name = ICONIC_TAXA.get(self.iconic_taxon_id, 'Unknown')
+
+        # If default photo is missing, use iconic taxon icon
         if not self.default_photo:
             self.default_photo = self.icon
 
+        # If only ancestor string (or objects) are provided, split into IDs
+        if self.ancestry and not self.ancestor_ids:
+            delimiter = ',' if ',' in self.ancestry else '/'
+            self.ancestor_ids = [int(x) for x in self.ancestry.split(delimiter)]
+        elif self.ancestors and not self.ancestor_ids:
+            self.ancestor_ids = [t.name for t in self.ancestors]
+
     @classmethod
     def from_sorted_json_list(cls, value: JsonResponse) -> List['Taxon']:
         """Sort Taxon objects by rank then by name"""
@@ -148,12 +162,6 @@ class Taxon(BaseModel):
         taxa.sort(key=_get_rank_name_idx)
         return taxa
 
-    @property
-    def ancestry(self) -> str:
-        """String containing either ancestor names (if available) or IDs"""
-        tokens = [t.name for t in self.ancestors] if self.ancestors else self.ancestor_ids
-        return ' | '.join([str(t) for t in tokens])
-
     @property
     def child_ids(self) -> List[int]:
         """Taxon IDs of direct children, sorted by rank then name"""
@@ -226,7 +234,7 @@ class Taxon(BaseModel):
             setattr(self, key, getattr(t, key))
 
     @property
-    def row(self) -> TableRow:
+    def _row(self) -> TableRow:
         return {
             'ID': self.id,
             'Rank': self.rank,
@@ -234,8 +242,9 @@ class Taxon(BaseModel):
             'Common name': self.preferred_common_name,
         }
 
-    def __str__(self) -> str:
-        return f'[{self.id}] {self.emoji} {self.full_name}'
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['id', 'full_name']
 
 
 @define_model
@@ -257,7 +266,7 @@ class TaxonCount(Taxon):
         return super(TaxonCount, cls).from_json(value)
 
     @property
-    def row(self) -> TableRow:
+    def _row(self) -> TableRow:
         return {
             'ID': self.id,
             'Rank': self.rank,
@@ -266,8 +275,9 @@ class TaxonCount(Taxon):
             'Count': self.count,
         }
 
-    def __str__(self) -> str:
-        return f'[{self.id}] {self.emoji} {self.full_name}: {self.count}'
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['id', 'full_name', 'count']
 
 
 @define_model_collection
