@@ -1,44 +1,35 @@
 from logging import getLogger
 from typing import List, Union
 
-from pyinaturalist.api_requests import delete, get, post, put
 from pyinaturalist.constants import (
     API_V0_BASE_URL,
     OBSERVATION_FORMATS,
-    REST_OBS_ORDER_BY_PROPERTIES,
+    V0_OBS_ORDER_BY_PROPERTIES,
     ListResponse,
     MultiFile,
 )
-from pyinaturalist.converters import (
-    convert_all_coordinates,
-    convert_all_timestamps,
-    ensure_file_obj,
-    ensure_list,
-)
+from pyinaturalist.converters import convert_all_coordinates, convert_all_timestamps, ensure_list
 from pyinaturalist.docs import document_request_params
 from pyinaturalist.docs import templates as docs
 from pyinaturalist.exceptions import ObservationNotFound
-from pyinaturalist.pagination import add_paginate_all
-from pyinaturalist.request_params import convert_observation_fields, validate_multiple_choice_param
+from pyinaturalist.request_params import convert_observation_params, validate_multiple_choice_param
+from pyinaturalist.session import delete, get, post, put
 
 logger = getLogger(__name__)
 
 
 @document_request_params(
-    [
-        docs._observation_common,
-        docs._observation_rest_only,
-        docs._bounding_box,
-        docs._pagination,
-    ]
+    docs._observation_common,
+    docs._observation_v0,
+    docs._bounding_box,
+    docs._pagination,
 )
-@add_paginate_all(method='page')
 def get_observations(**params) -> Union[List, str]:
-    """Get observation data, optionally in an alternative format. Also see
-    :py:func:`.get_geojson_observations` for GeoJSON format (not included here because it wraps
-    a separate API endpoint).
+    """Get observation data, optionally in an alternative format
 
-    **API reference:** https://www.inaturalist.org/pages/api+reference#get-observations
+    .. rubric:: Notes
+
+    * API reference: :v0:`GET /observations <get-observations>`
 
     Example:
 
@@ -83,11 +74,9 @@ def get_observations(**params) -> Union[List, str]:
         Return type will be ``dict`` for the ``json`` response format, and ``str`` for all others.
     """
     response_format = params.pop('response_format', 'json')
-    if response_format == 'geojson':
-        raise ValueError('For geojson format, use pyinaturalist.v1.get_geojson_observations')
     if response_format not in OBSERVATION_FORMATS:
         raise ValueError('Invalid response format')
-    validate_multiple_choice_param(params, 'order_by', REST_OBS_ORDER_BY_PROPERTIES)
+    validate_multiple_choice_param(params, 'order_by', V0_OBS_ORDER_BY_PROPERTIES)
 
     response = get(f'{API_V0_BASE_URL}/observations.{response_format}', **params)
     if response_format == 'json':
@@ -99,18 +88,21 @@ def get_observations(**params) -> Union[List, str]:
         return response.text
 
 
-@document_request_params([docs._access_token, docs._create_observation])
-def create_observation(access_token: str, **params) -> ListResponse:
-    """Create a new observation.
+@document_request_params(docs._access_token, docs._create_observation)
+def create_observation(**params) -> ListResponse:
+    """Create a new observation
 
-    **API reference:** https://www.inaturalist.org/pages/api+reference#post-observations
+    .. rubric:: Notes
+
+    * :fa:`lock` :ref:`Requires authentication <auth>`
+    * API reference: :v0:`POST /observations <post-observations>`
 
     Example:
         >>> token = get_access_token()
         >>> create_observation(
         >>>     access_token=token,
         >>>     species_guess='Pieris rapae',
-        >>>     local_photos='~/observation_photos/2020_09_01_14003156.jpg',
+        >>>     photos='~/observation_photos/2020_09_01_14003156.jpg',
         >>>     observation_fields={297: 1},  # 297 is the obs. field ID for 'Number of individuals'
         >>> )
 
@@ -130,43 +122,37 @@ def create_observation(access_token: str, **params) -> ListResponse:
         JSON response containing the newly created observation(s)
 
     Raises:
-        :py:exc:`requests.HTTPError`, if the call is not successful. iNaturalist returns an
-        error 422 (unprocessable entity) if it rejects the observation data (for example an
-        observation date in the future or a latitude > 90. In that case the exception's
-        ``response`` attribute gives more details about the errors.
+        :py:exc:`~urllib3.exceptions.HTTPError`: If the call is not successful. The exception's ``response`` attribute gives more details about the errors.
     """
-
-    params, photos, sounds, user_agent, session = _process_observation_params(params)
+    photos, sounds, _, params, kwargs = convert_observation_params(params)
     response = post(
         url=f'{API_V0_BASE_URL}/observations.json',
         json={'observation': params},
-        access_token=access_token,
-        user_agent=user_agent,
-        session=session,
+        **kwargs,
     )
     response_json = response.json()
     observation_id = response_json[0]['id']
 
     if photos:
-        upload_photos(observation_id, photos, access_token)
+        upload_photos(observation_id, photos, **kwargs)
     if sounds:
-        upload_sounds(observation_id, sounds, access_token)
+        upload_sounds(observation_id, sounds, **kwargs)
     return response_json
 
 
 @document_request_params(
-    [
-        docs._observation_id,
-        docs._access_token,
-        docs._create_observation,
-        docs._update_observation,
-    ]
+    docs._observation_id,
+    docs._access_token,
+    docs._create_observation,
+    docs._update_observation,
 )
-def update_observation(observation_id: int, access_token: str, **params) -> ListResponse:
-    """
-    Update a single observation.
+def update_observation(observation_id: int, **params) -> ListResponse:
+    """Update a single observation
 
-    **API reference:** https://www.inaturalist.org/pages/api+reference#put-observations-id
+    .. rubric:: Notes
+
+    * :fa:`lock` :ref:`Requires authentication <auth>`
+    * API reference: :v0:`PUT /observations/{id} <put-observations-id>`
 
     .. note::
 
@@ -191,54 +177,34 @@ def update_observation(observation_id: int, access_token: str, **params) -> List
                 :language: javascript
 
     Returns:
-        JSON response containing the newly updated observation(s)
+        JSON response containing the newly updated observation
 
     Raises:
-        :py:exc:`requests.HTTPError`, if the call is not successful. iNaturalist returns an
-            error 410 if the observation doesn't exists or belongs to another user.
+        :py:exc:`~urllib3.exceptions.HTTPError`: if the call is not successful. iNaturalist returns an error 410 if the observation doesn't exists or belongs to another user.
     """
-    params, photos, sounds, user_agent, session = _process_observation_params(params)
+    photos, sounds, _, params, kwargs = convert_observation_params(params)
     response = put(
         url=f'{API_V0_BASE_URL}/observations/{observation_id}.json',
         json={'observation': params},
-        access_token=access_token,
-        user_agent=user_agent,
-        session=session,
+        **kwargs,
     )
 
     if photos:
-        upload_photos(observation_id, photos, access_token)
+        upload_photos(observation_id, photos, **kwargs)
     if sounds:
-        upload_sounds(observation_id, sounds, access_token)
+        upload_sounds(observation_id, sounds, **kwargs)
     return response.json()
 
 
-def _process_observation_params(params):
-    params = convert_observation_fields(params)
-    if params.get('observed_on'):
-        params['observed_on_string'] = params.pop('observed_on')
+def upload_photos(observation_id: int, photos: MultiFile, **params) -> ListResponse:
+    """Upload a local photo and assign it to an existing observation
 
-    # Split out photos and sounds to upload separately
-    photos = ensure_list(params.pop('local_photos', None))
-    photos.extend(ensure_list(params.pop('photos', None)))  # Alias for 'local_photos'
-    sounds = ensure_list(params.pop('sounds', None))
+    .. rubric:: Notes
 
-    # Note: this is the only Boolean parameter that's specified as an int
-    if 'ignore_photos' in params:
-        params['ignore_photos'] = int(params['ignore_photos'])
-    else:
-        params['ignore_photos'] = 1
-
-    user_agent = params.pop('user_agent', None)
-    session = params.pop('session', None)
-    return params, photos, sounds, user_agent, session
-
-
-def upload_photos(observation_id: int, photos: MultiFile, access_token: str, **params) -> ListResponse:
-    """Upload a local photo and assign it to an existing observation.
+    * :fa:`lock` :ref:`Requires authentication <auth>`
+    * API reference: :v0:`POST /observation_photos <post-observation_photos>`
 
     Example:
-
         >>> token = get_access_token()
         >>> upload_photos(1234, '~/observations/2020_09_01_14003156.jpg', access_token=token)
 
@@ -259,7 +225,7 @@ def upload_photos(observation_id: int, photos: MultiFile, access_token: str, **p
     Args:
         observation_id: the ID of the observation
         photo: An image file, file-like object, or path
-        access_token: the access token, as returned by :func:`get_access_token()`
+        access_token: Access token for user authentication, as returned by :func:`get_access_token()`
 
     Returns:
         Information about the uploaded photo(s)
@@ -269,8 +235,7 @@ def upload_photos(observation_id: int, photos: MultiFile, access_token: str, **p
     for photo in ensure_list(photos):
         response = post(
             url=f'{API_V0_BASE_URL}/observation_photos',
-            access_token=access_token,
-            files={'file': ensure_file_obj(photo)},
+            files=photo,
             raise_for_status=False,
             **{'observation_photo[observation_id]': observation_id},
             **params,
@@ -283,11 +248,14 @@ def upload_photos(observation_id: int, photos: MultiFile, access_token: str, **p
     return [response.json() for response in responses]
 
 
-def upload_sounds(observation_id: int, sounds: MultiFile, access_token: str, **params) -> ListResponse:
-    """Upload a local sound file and assign it to an existing observation.
+def upload_sounds(observation_id: int, sounds: MultiFile, **params) -> ListResponse:
+    """Upload a local sound file and assign it to an existing observation
+
+    .. rubric:: Notes
+
+    * :fa:`lock` :ref:`Requires authentication <auth>`
 
     Example:
-
         >>> token = get_access_token()
         >>> upload_sounds(1234, '~/observations/2020_09_01_14003156.mp3', access_token=token)
 
@@ -308,7 +276,7 @@ def upload_sounds(observation_id: int, sounds: MultiFile, access_token: str, **p
     Args:
         observation_id: the ID of the observation
         sound: An audio file, file-like object, or path
-        access_token: the access token, as returned by :func:`get_access_token()`
+        access_token: Access token for user authentication, as returned by :func:`get_access_token()`
 
     Returns:
         Information about the uploaded sound(s)
@@ -318,8 +286,7 @@ def upload_sounds(observation_id: int, sounds: MultiFile, access_token: str, **p
     for sound in ensure_list(sounds):
         response = post(
             url=f'{API_V0_BASE_URL}/observation_sounds',
-            access_token=access_token,
-            files={'file': ensure_file_obj(sound)},
+            files=sound,
             raise_for_status=False,
             **{'observation_sound[observation_id]': observation_id},
             **params,
@@ -332,15 +299,17 @@ def upload_sounds(observation_id: int, sounds: MultiFile, access_token: str, **p
     return [response.json() for response in responses]
 
 
-@document_request_params([docs._observation_id, docs._access_token])
-def delete_observation(observation_id: int, access_token: str = None, **params):
+@document_request_params(docs._observation_id, docs._access_token)
+def delete_observation(observation_id: int, **params):
     """
-    Delete an observation.
+    Delete an observation
 
-    **API reference:** https://www.inaturalist.org/pages/api+reference#delete-observations-id
+    .. rubric:: Notes
+
+    * :fa:`lock` :ref:`Requires authentication <auth>`
+    * API reference: :v0:`DELETE /observations/{id} <delete-observations-id>`
 
     Example:
-
         >>> token = get_access_token()
         >>> delete_observation(17932425, token)
 
@@ -348,12 +317,11 @@ def delete_observation(observation_id: int, access_token: str = None, **params):
         If successful, no response is returned from this endpoint
 
     Raises:
-        :py:exc:`.ObservationNotFound` if the requested observation doesn't exist
-        :py:exc:`requests.HTTPError` (403) if the observation belongs to another user
+        :py:exc:`.ObservationNotFound`: if the requested observation doesn't exist
+        :py:exc:`~urllib3.exceptions.HTTPError`: 403 if the observation belongs to another user
     """
     response = delete(
         url=f'{API_V0_BASE_URL}/observations/{observation_id}.json',
-        access_token=access_token,
         raise_for_status=False,
         **params,
     )
