@@ -2,18 +2,19 @@ from pyinaturalist.constants import JsonResponse, MultiInt
 from pyinaturalist.converters import convert_all_timestamps
 from pyinaturalist.docs import document_request_params
 from pyinaturalist.docs import templates as docs
-from pyinaturalist.pagination import add_paginate_all
+from pyinaturalist.paginator import paginate_all
 from pyinaturalist.request_params import convert_rank_range
 from pyinaturalist.v1 import get_v1
 
 
 def get_identifications_by_id(identification_id: MultiInt, **params) -> JsonResponse:
-    """Get one or more identification records by ID.
+    """Get one or more identification records by ID
 
-    **API reference:** https://api.inaturalist.org/v1/docs/#!/Identifications/get_identifications_id
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /identifications/{id} <Identifications/get_identifications_id>`
 
     Example:
-
         >>> get_identifications_by_id(155554373)
 
         .. admonition:: Example Response
@@ -33,15 +34,15 @@ def get_identifications_by_id(identification_id: MultiInt, **params) -> JsonResp
     return identifications
 
 
-@document_request_params([docs._identification_params, docs._pagination, docs._only_id])
-@add_paginate_all(method='page')
+@document_request_params(docs._identification_params, docs._pagination, docs._only_id)
 def get_identifications(**params) -> JsonResponse:
-    """Search identifications.
+    """Search identifications
 
-    **API reference:** https://api.inaturalist.org/v1/docs/#!/Identifications/get_identifications
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /identifications <Identifications/get_identifications>`
 
     Example:
-
         Get all of your own species-level identifications:
 
         >>> response = get_identifications(user_login='my_username', rank='species')
@@ -60,7 +61,10 @@ def get_identifications(**params) -> JsonResponse:
         Response dict containing identification records
     """
     params = convert_rank_range(params)
-    response = get_v1('identifications', **params)
-    identifications = response.json()
+    if params.get('page') == 'all':
+        identifications = paginate_all(get_v1, 'identifications', **params)
+    else:
+        identifications = get_v1('identifications', **params).json()
+
     identifications['results'] = convert_all_timestamps(identifications['results'])
     return identifications
