@@ -14,6 +14,7 @@ from pyinaturalist.converters import (
     convert_all_timestamps,
     convert_generic_timestamps,
     convert_histogram,
+    convert_observation_histogram,
     convert_observation_timestamps,
     ensure_list,
 )
@@ -110,7 +111,7 @@ def get_observation_histogram(**params) -> HistogramResponse:
         'week of year' intervals, and :py:class:`~datetime.datetime` objects for all other intervals.
     """
     response = get_v1('observations/histogram', **params)
-    return convert_histogram(response.json())
+    return convert_observation_histogram(response.json())
 
 
 @document_request_params(*docs._get_observations, docs._pagination, docs._only_id)
@@ -121,7 +122,7 @@ def get_observations(**params) -> JsonResponse:
 
     * API reference: :v1:`GET /observations <Observations/get_observations>`
 
-    Example:
+    Examples:
 
         Get observations of Monarch butterflies with photos + public location info,
         on a specific date in the provice of Saskatchewan, CA (place ID 7953):
@@ -161,6 +162,71 @@ def get_observations(**params) -> JsonResponse:
     return observations
 
 
+@document_request_params(*docs._get_observations, docs._pagination)
+def get_observation_identifiers(**params) -> JsonResponse:
+    """Get identifiers of observations matching the search criteria and the count of
+    observations they have identified. By default, results are sorted by ID count in descending.
+
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /observations/identifiers <Observations/get_observations_identifiers>`
+    * This endpoint will only return up to 500 results.
+
+    Example:
+        >>> response = get_observation_identifiers(place_id=72645)
+        >>> pprint(response)
+        [409010  ] jdoe42 (Jane Doe)
+        [691216  ] jbrown252 (James Brown)
+        [3959037 ] tnsparkleberry
+
+        .. admonition:: Example Response
+            :class: toggle
+
+            .. literalinclude:: ../sample_data/get_observation_identifiers_ex_results.json
+                :language: JSON
+
+    Returns:
+        Response dict of identifiers
+    """
+    params.setdefault('per_page', 500)
+    response = get_v1('observations/identifiers', **params)
+    return response.json()
+
+
+@document_request_params(*docs._get_observations, docs._pagination)
+def get_observation_observers(**params) -> JsonResponse:
+    """Get observers of observations matching the search criteria and the count of
+    observations and distinct taxa of rank species they have observed.
+
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /observations/observers <Observations/get_observations_observers>`
+    * Options for ``order_by`` are 'observation_count' (default) or 'species_count'
+    * This endpoint will only return up to 500 results
+    * See this issue for more details: https://github.com/inaturalist/iNaturalistAPI/issues/235
+
+    Example:
+        >>> response = get_observation_observers(place_id=72645, order_by='species_count')
+        >>> pprint(response)
+        [1566366 ] fossa1211
+        [674557  ] schurchin
+        [5813    ] fluffberger (Fluff Berger)
+
+
+        .. admonition:: Example Response
+            :class: toggle
+
+            .. literalinclude:: ../sample_data/get_observation_observers_ex_results.json
+                :language: JSON
+
+    Returns:
+        Response dict of observers
+    """
+    params.setdefault('per_page', 500)
+    response = get_v1('observations/observers', **params)
+    return response.json()
+
+
 @document_request_params(*docs._get_observations, docs._pagination)
 def get_observation_species_counts(**params) -> JsonResponse:
     """Get all species (or other 'leaf taxa') associated with observations matching the search
@@ -193,69 +259,32 @@ def get_observation_species_counts(**params) -> JsonResponse:
         return get_v1('observations/species_counts', **params).json()
 
 
-@document_request_params(*docs._get_observations, docs._pagination)
-def get_observation_observers(**params) -> JsonResponse:
-    """Get observers of observations matching the search criteria and the count of
-    observations and distinct taxa of rank species they have observed.
+@document_request_params(*docs._get_observations)
+def get_observation_popular_field_values(**params) -> JsonResponse:
+    """Get controlled terms values and a monthly histogram of observations matching the search
 
     .. rubric:: Notes
 
-    * API reference: :v1:`GET /observations/observers <Observations/get_observations_observers>`
-    * Options for ``order_by`` are 'observation_count' (default) or 'species_count'
-    * This endpoint will only return up to 500 results
-    * See this issue for more details: https://github.com/inaturalist/iNaturalistAPI/issues/235
+    * API reference: :v1:`GET /observations/popular_field_values <Observations/get_observations_popular_field_values>`
 
     Example:
-        >>> response = get_observation_observers(place_id=72645, order_by='species_count')
-        >>> pprint(response, align=True)
-        [1566366 ] fossa1211
-        [674557  ] schurchin
-        [5813    ] fluffberger (Fluff Berger)
-
+        >>> response = get_observation_popular_field_values(
+        ...     species_name='Danaus plexippus', place_id=24,
+        ... )
 
         .. admonition:: Example Response
             :class: toggle
 
-            .. literalinclude:: ../sample_data/get_observation_observers_ex_results.json
-                :language: JSON
+            .. literalinclude:: ../sample_data/get_observation_popular_field_values.py
 
     Returns:
-        Response dict of observers
+        Response dict. Each record contains a ``count``, a ``month_of_year`` histogram, a
+            ``controlled_attribute``, and a ``controlled_value``.
     """
-    params.setdefault('per_page', 500)
-    response = get_v1('observations/observers', **params)
-    return response.json()
-
-
-@document_request_params(*docs._get_observations, docs._pagination)
-def get_observation_identifiers(**params) -> JsonResponse:
-    """Get identifiers of observations matching the search criteria and the count of
-    observations they have identified. By default, results are sorted by ID count in descending.
-
-    .. rubric:: Notes
-
-    * API reference: :v1:`GET /observations/identifiers <Observations/get_observations_identifiers>`
-    * This endpoint will only return up to 500 results.
-
-    Example:
-        >>> response = get_observation_identifiers(place_id=72645)
-        >>> pprint(response)
-        [409010  ] jdoe42 (Jane Doe)
-        [691216  ] jbrown252 (James Brown)
-        [3959037 ] tnsparkleberry
-
-        .. admonition:: Example Response
-            :class: toggle
-
-            .. literalinclude:: ../sample_data/get_observation_identifiers_ex_results.json
-                :language: JSON
-
-    Returns:
-        Response dict of identifiers
-    """
-    params.setdefault('per_page', 500)
-    response = get_v1('observations/identifiers', **params)
-    return response.json()
+    response_json = get_v1('observations/popular_field_values', **params).json()
+    for r in response_json['results']:
+        r['month_of_year'] = convert_histogram(r['month_of_year'], interval='month_of_year')
+    return response_json
 
 
 def get_observation_taxonomy(user_id: IntOrStr = None, **params) -> JsonResponse:
