@@ -1,13 +1,14 @@
-import pytest
-from datetime import date, datetime
-from dateutil.tz import gettz
+from datetime import date, datetime, timedelta
 from unittest.mock import patch
 
+import pytest
+from dateutil.tz import gettz
+
 from pyinaturalist.request_params import (
     convert_bool_params,
     convert_datetime_params,
     convert_list_params,
-    convert_observation_fields,
+    convert_observation_field_params,
     convert_pagination_params,
     get_interval_ranges,
     preprocess_request_body,
@@ -64,7 +65,7 @@ def test_convert_list_params():
 
 
 def test_convert_observation_fields():
-    params = convert_observation_fields(TEST_PARAMS)
+    params = convert_observation_field_params(TEST_PARAMS)
     assert params['observation_field_values_attributes'] == [
         {'observation_field_id': 1, 'value': 'value'}
     ]
@@ -78,51 +79,67 @@ def test_convert_pagination_params():
     assert params['per_page'] == 0
     assert 'count_only' not in params
 
-    params = convert_pagination_params({'per_page': 100, 'count_only': False})
+    params = convert_pagination_params({'per_page': 100, 'count_only': False, 'reverse': True})
     assert params['per_page'] == 100
-    assert 'count_only' not in params
+    assert params['order'] == 'descending'
+    assert 'reverse' not in params
 
 
-def test_get_interval_ranges__monthly():
+@pytest.mark.parametrize(
+    'start, end, interval',
+    [
+        (datetime(2020, 1, 1), datetime(2020, 1, 5), 'day'),
+        ('2020-01-01', '2020-01-05', 'day'),
+        ('2020-01-01', '2020-01-05', timedelta(days=1)),
+    ],
+)
+def test_get_interval_ranges__day(start, end, interval):
     expected_ranges = [
-        (datetime(2020, 1, 1, 0, 0), datetime(2020, 1, 31, 0, 0)),
-        (datetime(2020, 2, 1, 0, 0), datetime(2020, 2, 29, 0, 0)),
-        (datetime(2020, 3, 1, 0, 0), datetime(2020, 3, 31, 0, 0)),
-        (datetime(2020, 4, 1, 0, 0), datetime(2020, 4, 30, 0, 0)),
-        (datetime(2020, 5, 1, 0, 0), datetime(2020, 5, 31, 0, 0)),
-        (datetime(2020, 6, 1, 0, 0), datetime(2020, 6, 30, 0, 0)),
-        (datetime(2020, 7, 1, 0, 0), datetime(2020, 7, 31, 0, 0)),
-        (datetime(2020, 8, 1, 0, 0), datetime(2020, 8, 31, 0, 0)),
-        (datetime(2020, 9, 1, 0, 0), datetime(2020, 9, 30, 0, 0)),
-        (datetime(2020, 10, 1, 0, 0), datetime(2020, 10, 31, 0, 0)),
-        (datetime(2020, 11, 1, 0, 0), datetime(2020, 11, 30, 0, 0)),
-        (datetime(2020, 12, 1, 0, 0), datetime(2020, 12, 31, 0, 0)),
+        (datetime(2020, 1, 1, 0, 0), datetime(2020, 1, 1, 23, 59)),
+        (datetime(2020, 1, 2, 0, 0), datetime(2020, 1, 2, 23, 59)),
+        (datetime(2020, 1, 3, 0, 0), datetime(2020, 1, 3, 23, 59)),
+        (datetime(2020, 1, 4, 0, 0), datetime(2020, 1, 4, 23, 59)),
+        (datetime(2020, 1, 5, 0, 0), datetime(2020, 1, 5, 23, 59)),
     ]
-    ranges = get_interval_ranges(datetime(2020, 1, 1), datetime(2020, 12, 31), 'monthly')
+    ranges = get_interval_ranges(start, end, interval)
     assert ranges == expected_ranges
 
 
-def test_get_interval_ranges__yearly():
+def test_get_interval_ranges__month():
     expected_ranges = [
-        (datetime(2010, 1, 1, 0, 0), datetime(2010, 12, 31, 0, 0)),
-        (datetime(2011, 1, 1, 0, 0), datetime(2011, 12, 31, 0, 0)),
-        (datetime(2012, 1, 1, 0, 0), datetime(2012, 12, 31, 0, 0)),
-        (datetime(2013, 1, 1, 0, 0), datetime(2013, 12, 31, 0, 0)),
-        (datetime(2014, 1, 1, 0, 0), datetime(2014, 12, 31, 0, 0)),
-        (datetime(2015, 1, 1, 0, 0), datetime(2015, 12, 31, 0, 0)),
-        (datetime(2016, 1, 1, 0, 0), datetime(2016, 12, 31, 0, 0)),
-        (datetime(2017, 1, 1, 0, 0), datetime(2017, 12, 31, 0, 0)),
-        (datetime(2018, 1, 1, 0, 0), datetime(2018, 12, 31, 0, 0)),
-        (datetime(2019, 1, 1, 0, 0), datetime(2019, 12, 31, 0, 0)),
-        (datetime(2020, 1, 1, 0, 0), datetime(2020, 12, 31, 0, 0)),
+        (datetime(2020, 1, 1, 0, 0), datetime(2020, 1, 31, 23, 59)),
+        (datetime(2020, 2, 1, 0, 0), datetime(2020, 2, 29, 23, 59)),
+        (datetime(2020, 3, 1, 0, 0), datetime(2020, 3, 31, 23, 59)),
+        (datetime(2020, 4, 1, 0, 0), datetime(2020, 4, 30, 23, 59)),
+        (datetime(2020, 5, 1, 0, 0), datetime(2020, 5, 31, 23, 59)),
+        (datetime(2020, 6, 1, 0, 0), datetime(2020, 6, 30, 23, 59)),
+        (datetime(2020, 7, 1, 0, 0), datetime(2020, 7, 31, 23, 59)),
+        (datetime(2020, 8, 1, 0, 0), datetime(2020, 8, 31, 23, 59)),
+        (datetime(2020, 9, 1, 0, 0), datetime(2020, 9, 30, 23, 59)),
+        (datetime(2020, 10, 1, 0, 0), datetime(2020, 10, 31, 23, 59)),
+        (datetime(2020, 11, 1, 0, 0), datetime(2020, 11, 30, 23, 59)),
+        (datetime(2020, 12, 1, 0, 0), datetime(2020, 12, 31, 23, 59)),
     ]
-    ranges = get_interval_ranges(datetime(2010, 1, 1), datetime(2020, 1, 1), 'yearly')
+    ranges = get_interval_ranges(datetime(2020, 1, 1), datetime(2020, 12, 31), 'month')
     assert ranges == expected_ranges
 
 
-def test_get_interval_ranges__invalid():
-    with pytest.raises(ValueError):
-        get_interval_ranges(datetime(2020, 1, 1), datetime(2020, 12, 31), 'daily')
+def test_get_interval_ranges__year():
+    expected_ranges = [
+        (datetime(2010, 1, 1, 0, 0), datetime(2010, 12, 31, 23, 59)),
+        (datetime(2011, 1, 1, 0, 0), datetime(2011, 12, 31, 23, 59)),
+        (datetime(2012, 1, 1, 0, 0), datetime(2012, 12, 31, 23, 59)),
+        (datetime(2013, 1, 1, 0, 0), datetime(2013, 12, 31, 23, 59)),
+        (datetime(2014, 1, 1, 0, 0), datetime(2014, 12, 31, 23, 59)),
+        (datetime(2015, 1, 1, 0, 0), datetime(2015, 12, 31, 23, 59)),
+        (datetime(2016, 1, 1, 0, 0), datetime(2016, 12, 31, 23, 59)),
+        (datetime(2017, 1, 1, 0, 0), datetime(2017, 12, 31, 23, 59)),
+        (datetime(2018, 1, 1, 0, 0), datetime(2018, 12, 31, 23, 59)),
+        (datetime(2019, 1, 1, 0, 0), datetime(2019, 12, 31, 23, 59)),
+        (datetime(2020, 1, 1, 0, 0), datetime(2020, 12, 31, 23, 59)),
+    ]
+    ranges = get_interval_ranges(datetime(2010, 1, 1), datetime(2020, 12, 31), 'year')
+    assert ranges == expected_ranges
 
 
 def test_strip_empty_params():
@@ -165,9 +182,9 @@ def test_preprocess_request_params(mock_bool, mock_datetime, mock_list, mock_str
 @patch('pyinaturalist.request_params.convert_datetime_params')
 @patch('pyinaturalist.request_params.convert_list_params')
 @patch('pyinaturalist.request_params.strip_empty_values')
-def test_preprocess_request_body(mock_bool, mock_datetime, mock_list, mock_strip):
+def test_preprocess_request_body(mock_bool, mock_list, mock_datetime, mock_strip):
     preprocess_request_body({'id': 1})
-    assert all([mock_bool.called, mock_datetime.called, mock_list.called, mock_strip.called])
+    assert all([mock_bool.called, mock_datetime.called, not mock_list.called, mock_strip.called])
 
 
 def test_validate_multiple_choice_param():
