@@ -1,14 +1,19 @@
+from time import sleep
 from unittest.mock import MagicMock, patch
 
 import pytest
+from requests import Request
+from requests_ratelimiter import Limiter, RequestRate
 
 from pyinaturalist.session import (
     CACHE_FILE,
     MOCK_RESPONSE,
     ClientSession,
+    clear_cache,
     delete,
     get,
     get_local_session,
+    get_refresh_params,
     post,
     put,
     request,
@@ -20,8 +25,9 @@ from pyinaturalist.session import (
     'http_func, http_method',
     [(delete, 'DELETE'), (get, 'GET'), (post, 'POST'), (put, 'PUT')],
 )
+@patch('pyinaturalist.session.format_response')
 @patch('pyinaturalist.session.Session.send')
-def test_http_methods(mock_send, http_func, http_method):
+def test_http_methods(mock_send, mock_format, http_func, http_method):
     http_func('https://url', key='value', session=None)
     request_obj = mock_send.call_args[0][0]
 
@@ -30,16 +36,18 @@ def test_http_methods(mock_send, http_func, http_method):
     assert request_obj.body is None
 
 
+@patch('pyinaturalist.session.format_response')
 @patch('pyinaturalist.session.Session.send')
-def test_request_headers(mock_send):
+def test_request_headers(mock_send, mock_format):
     """Test that the request() wrapper passes along expected headers"""
     request('GET', 'https://url', access_token='token')
     request_obj = mock_send.call_args[0][0]
     assert request_obj.headers['Authorization'] == 'Bearer token'
 
 
+@patch('pyinaturalist.session.format_response')
 @patch('pyinaturalist.session.ClientSession')
-def test_request_session(mock_ClientSession):
+def test_request_session(mock_ClientSession, mock_format):
     mock_session = MagicMock()
     request('GET', 'https://url', session=mock_session)
     mock_session.send.assert_called()
@@ -73,11 +81,13 @@ def test_request_session(mock_ClientSession):
         (False, 'None', 'DELETE', True),
     ],
 )
+@patch('pyinaturalist.session.format_response')
 @patch('pyinaturalist.session.getenv')
 @patch('pyinaturalist.session.Session.send')
 def test_request_dry_run(
     mock_send,
     mock_getenv,
+    mock_format,
     enabled_env,
     write_only_env,
     method,
@@ -120,13 +130,13 @@ def test_request_dry_run_disabled(requests_mock):
 
 def test_session__cache_file():
     session = ClientSession()
-    assert session.cache.responses.db_path == CACHE_FILE
+    assert str(session.cache.responses.db_path) == CACHE_FILE
 
 
 def test_session__custom_expiration():
     session = ClientSession(expire_after=3600)
-    assert session.expire_after == 3600
-    assert session.urls_expire_after is None
+    assert session.settings.expire_after == 3600
+    assert not session.settings.urls_expire_after
 
 
 def test_session__custom_retry():
@@ -136,11 +146,25 @@ def test_session__custom_retry():
 
 
 @patch('requests.sessions.Session.send')
-def test_session__send(mock_session):
+@patch('requests_ratelimiter.requests_ratelimiter.Limiter')
+def test_session__send(mock_limiter, mock_requests_send):
     session = ClientSession()
-    request = MagicMock(method='GET', url='http://test.com')
+    request = Request(method='GET', url='http://test.com').prepare()
     session.send(request)
-    mock_session.assert_called_with(request, timeout=10)
+    mock_requests_send.assert_called_with(request, timeout=(5, 10))
+
+
+@pytest.mark.enable_client_session  # For all other tests, caching is disabled. Re-enable that here.
+@patch('requests_cache.session.CacheMixin.send')
+def test_session__send__cache_settings(mock_cache_send):
+    session = ClientSession()
+    request = Request(method='GET', url='http://test.com').prepare()
+
+    session.send(request)
+    mock_cache_send.assert_called_with(request, expire_after=None, refresh=False, timeout=(5, 10))
+
+    session.send(request, expire_after=60, refresh=True)
+    mock_cache_send.assert_called_with(request, expire_after=60, refresh=True, timeout=(5, 10))
 
 
 def test_get_local_session():
@@ -148,3 +172,21 @@ def test_get_local_session():
     session_2 = get_local_session()
     assert session_1 is session_2
     assert isinstance(session_1, ClientSession)
+
+
+@pytest.mark.enable_client_session
+def test_clear_cache():
+    session = get_local_session()
+    with patch.object(session, 'cache', autospec=True) as mock_cache:
+        clear_cache()
+        mock_cache.clear.assert_called()
+
+
+@patch('pyinaturalist.session.REFRESH_LIMITER', Limiter(RequestRate(1, 2)))
+def test_get_refresh_params():
+    assert get_refresh_params('test') == {'refresh': True}
+    assert get_refresh_params('test2') == {'refresh': True}
+    assert get_refresh_params('test') == {'refresh': True, 'v': 1}
+    assert get_refresh_params('test') == {'refresh': True, 'v': 2}
+    sleep(2)
+    assert get_refresh_params('test') == {'refresh': True}
