@@ -1,9 +1,9 @@
-import pytest
 from datetime import datetime, timedelta
-from dateutil.tz import tzutc
 from io import BytesIO
 from unittest.mock import patch
 
+import pytest
+from dateutil.tz import tzutc
 from requests import HTTPError
 
 from pyinaturalist.constants import API_V0_BASE_URL, OBSERVATION_FORMATS
@@ -42,8 +42,12 @@ def test_get_observations(response_format, requests_mock):
     if response_format == 'json':
         assert observations[0]['latitude'] == 50.646894
         assert observations[0]['longitude'] == 4.360086
-        assert observations[0]['created_at'] == datetime(2018, 9, 5, 12, 31, 8, 48000, tzinfo=tzutc())
-        assert observations[0]['updated_at'] == datetime(2018, 9, 22, 17, 19, 27, 80000, tzinfo=tzutc())
+        assert observations[0]['created_at'] == datetime(
+            2018, 9, 5, 12, 31, 8, 48000, tzinfo=tzutc()
+        )
+        assert observations[0]['updated_at'] == datetime(
+            2018, 9, 22, 17, 19, 27, 80000, tzinfo=tzutc()
+        )
     else:
         assert observations == mock_response
 
@@ -72,7 +76,7 @@ def test_create_observation(requests_mock):
 @patch('pyinaturalist.v0.observations.post')
 def test_create_observation__with_datetime(post, requests_mock):
     """Just test that request param aliases work. Datetimes are converted to strings separately in
-    request_params.prepare_request().
+    prepare_request().
     """
     requests_mock.post(
         f'{API_V0_BASE_URL}/observations.json',
